File: 0002-fix-spelling.patch

package info (click to toggle)
paexec 1.1.1-1
  • links: PTS, VCS
  • area: main
  • in suites: bookworm, bullseye, sid, trixie
  • size: 904 kB
  • sloc: sh: 3,435; ansic: 1,959; makefile: 174; pascal: 19
file content (132 lines) | stat: -rw-r--r-- 3,942 bytes parent folder | download
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
From: Alexander Ponyatykh <lazyranma@gmail.com>
Date: Sun, 24 Nov 2019 02:20:04 +0300
Subject: Fix spelling

---
 paargs/paargs.pod         | 2 +-
 paexec/paexec.c           | 4 ++--
 paexec/paexec.pod         | 2 +-
 paexec/paexec_reorder.pod | 2 +-
 paexec/tasks.c            | 2 +-
 5 files changed, 6 insertions(+), 6 deletions(-)

--- a/paargs/paargs.pod
+++ b/paargs/paargs.pod
@@ -26,7 +26,7 @@
 =item *
 
 I<-l> -- 0-based task number is included to the output of B<paargs>, this
-allows to reorder the sliced output,
+allows one to reorder the sliced output,
 
 =item *
 
@@ -79,7 +79,7 @@
 
 =item B<-f>
 
-Flushes stdout after recieving an end-of-task line.
+Flushes stdout after receiving an end-of-task line.
 
 =item B<-0>
 
--- a/paexec/paexec.c
+++ b/paexec/paexec.c
@@ -96,7 +96,7 @@
   -d               debug mode, for debugging only\n\
 \n\
   -z               failed nodes are marked as dead\n\
-  -Z <timeout>     timeout to restart faild command, imply -z\n\
+  -Z <timeout>     timeout to restart failed command, imply -z\n\
   -w               wait for restoring nodes (needs -Z)\n\
 \n\
   -W               heavier tasks are processed first, a weight\n\
@@ -627,7 +627,7 @@
 		return;
 
 	if (debug)
-		printf ("wait for childs\n");
+		printf ("wait for children\n");
 
 	for (i=0; i < nodes_count; ++i){
 		if (pids [i] != (pid_t) -1){
--- a/paexec/paexec.pod
+++ b/paexec/paexec.pod
@@ -274,7 +274,7 @@
 
 When I<-z> applied, if a I<command> fails, appropriate node is marked
 as broken and is excluded from the following task distribution. But if
-B<-Z> applied, every I<timeout> seconds an attempt to rerun a comand
+B<-Z> applied, every I<timeout> seconds an attempt to rerun a command
 on a failed node is made. I<-Z> implies I<-z>. This option makes
 possible to organize clusters over unreliable networks/hardware.
 
--- a/paexec/paexec_reorder.pod
+++ b/paexec/paexec_reorder.pod
@@ -11,7 +11,7 @@
 B<paexec> with -l option produces a sliced output where results of
 different tasks are intermixed. The intent of B<paexec_reorder> is to
 produce ordered output where results for all tasks follow each other
-without intermixing. It is strongly recomended to send output of
+without intermixing. It is strongly recommended to send output of
 "B<paexec> I<-le>" or "B<paexec> I<-gle>" to the input of B<paexec_reorder>. Otherwise
 more memory or disk space for temporary files will be required.
 
--- a/paexec/tasks.c
+++ b/paexec/tasks.c
@@ -368,7 +368,7 @@
 		switch (check_cycles__mark [to]){
 			case 2:
 				loop = 0;
-				fprintf (stderr, "Cyclic dependancy detected:\n");
+				fprintf (stderr, "Cyclic dependency detected:\n");
 				for (j=1; j <= stack_sz; ++j){
 					s = check_cycles__stack [j-1];
 					t = check_cycles__stack [j];
--- a/tests/test.sh
+++ b/tests/test.sh
@@ -2016,7 +2016,7 @@
 ok100
 '
 
     # diamond-like dependancy and failure
     runtest -l -s -C -n +5 cmd_xxx_failed_make_package flex \
 	> $OBJDIR/_test.tmp < ../examples/make_package/tasks2
 
@@ -2044,7 +2044,7 @@
 	-c cmd_make_package \
 	-n +5 < ../examples/make_package/tasks_cycle |
     cmp 'paexec cyclic deps #1' \
-'Cyclic dependancy detected:
+'Cyclic dependency detected:
   devel/gettext-lib -> devel/gmake
   devel/gmake -> lang/gcc
   lang/gcc -> devel/gettext-lib
@@ -2061,7 +2061,7 @@
 	-c cmd_make_package \
 	-n +5 |
     cmp 'paexec cyclic deps #2' \
-'Cyclic dependancy detected:
+'Cyclic dependency detected:
   task10 -> task20
   task20 -> task30
   task30 -> task10
@@ -2077,7 +2077,7 @@
 	-c cmd_make_package \
 	-n +5 |
     cmp 'paexec cyclic deps #3' \
-'Cyclic dependancy detected:
+'Cyclic dependency detected:
   task50 -> task50
 '
 
@@ -2096,7 +2096,7 @@
 	-c cmd_make_package \
 	-n +5 |
     cmp 'paexec cyclic deps #4' \
-'Cyclic dependancy detected:
+'Cyclic dependency detected:
   task0 -> task200
   task200 -> task300
   task300 -> task0
@@ -2016,7 +2016,7 @@
 '
 
-    # diamond-like dependancy and failure
+    # diamond-like dependency and failure
     runtest -l -s -C -n +5 cmd_xxx_failed_make_package flex \
 	> $OBJDIR/_test.tmp < ../examples/make_package/tasks2